# Threshold Gate

Draw a threshold gate. To set a new threshold, click on the plot.

Name

  The operation name. Used to name the new metadata field that’s created by this module.

Channel

  The name of the channel to apply the gate to.

Threshold

  The threshold of the gate.

Scale

  The scale of the axis for the interactive plot

Hue facet

  Show different experimental conditions in different colors.

Subset

  Show only a subset of the data.